@@ -325,13 +325,14 @@ class account():
                 n = pynotify.Notification("Witter","You have "+str(receive_count)+" new mentions")
                 n.set_urgency(pynotify.URGENCY_CRITICAL)
                 icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
-
+                #n.add_action("clicked","Show DMs", self.dm_callback)
+                n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_mentions")
                 n.set_icon_from_pixbuf(icon)
                 rpc = osso.Rpc(self.osso_c)
                 rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
                 rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
                 #n.attach_to_widget(self.controller.ui.window)
-                n.add_action("clicked","Show DMs", self.mentions_callback)
+                
                 n.show()
 
         except IOError, e:
@@ -406,17 +407,18 @@ class account():
             if (receive_count > 0):
                 #note = osso.SystemNote(self.osso_c)
                 #result = note.system_note_infoprint(str(receive_count) + " DMs Received")
-                #n = pynotify.Notification("Witter","You have "+str(receive_count)+" new DMs")
+                n = pynotify.Notification("Witter","You have "+str(receive_count)+" new DMs")
                 icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
-                self.dmnotify.set_icon_from_pixbuf(icon)                
-                self.dmnotify.set_urgency(pynotify.URGENCY_CRITICAL)
+                n.set_icon_from_pixbuf(icon)                
+                n.set_urgency(pynotify.URGENCY_CRITICAL)
+                n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_dm")
                 rpc = osso.Rpc(self.osso_c)
                 rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
                 rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
                 #dmnotify.add_action("clicked","Show DMs", self.dm_callback)
 
                 #n.attach_to_widget(self.controller.ui.window)
-                self.dmnotify.show()
+                n.show()
         except IOError, e:
             print "error"
             msg = 'Error retrieving dms '
@@ -830,6 +832,30 @@ class account():
                 data = self.api.CreateFriendship(name)
                 note = osso.SystemNote(self.osso_c)
                 result = note.system_note_infoprint("Now following " + name)
+                #fetching tweets for newly followed user to add to timeline
+                data = self.api.GetUserTimeline(id=data.GetId())
+
+                for x in data:
+
+                    if (None != x.in_reply_to_status_id):
+                        print "reply to " + x.in_reply_to_screen_name
+                        #we don't want anything showing up if there is no reply_to, so all teh formatting is held here including the newline
+                        reply_to = "In reply to: " + x.in_reply_to_screen_name + " - " + self.get_specific_tweet(x.in_reply_to_screen_name, x.in_reply_to_status_id)
+                    else:
+                        reply_to = ""
+
+                    reply_to = reply_to.replace("&", "&amp;")
+
+                    #strip the source app name from the url
+                    source = self.getSourceAppname(x.source)
+                    text = self.escapeText(x.text)
+                    text = self.controller.expandBitlyUrls(text)
+                    pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
+                    created_at = self.parse_time(x.created_at)
+                    formatted_ts = self.format_timestamp(created_at)
+                    formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
+                    self.tweetstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                 
         except IOError, e:
             print "error"
             msg = 'Error following ' + name + ' '
@@ -918,7 +944,14 @@ class account():
             item = self.avatars.iter_next(item)
         #if we make it here we didn't have it loaded already
         if (os.path.isfile("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)):
-            pixbuf = gtk.gdk.pixbuf_new_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
+            try:
+                pixbuf = gtk.gdk.pixbuf_new_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
+            except GError:
+                #failed to load file, delete it, and go fetch a new one
+                print "corrupted avatar file found, deleting it"
+                os.remove("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
+                print "bad file deleted, returning default icon"
+                pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
             pixbuf = pixbuf.scale_simple(self.avatar_size, self.avatar_size, gtk.gdk.INTERP_BILINEAR)
             self.avatars.append([pixbuf, filename, 1, name])
             
