@@ -1310,7 +1310,7 @@ class Api(object):
     self._InitializeDefaultParameters()
     self._input_encoding = input_encoding
     self.SetCredentials(username, password)
-    self._base_url = "https://api.twitter.com/1/"
+    self._base_url = "https://twitter.com/"
     self._base_search_url = "https://search.twitter.com/"
 
   def GetPublicTimeline(self, since_id=None):
@@ -1809,6 +1809,23 @@ class Api(object):
     self._CheckForTwitterError(data)
     return Status.NewFromJsonDict(data)
 
+  def CreateFavoriteForID(self, id):
+    '''Favorites the status specified in the status parameter as the authenticating user.
+    Returns the favorite status when successful.
+
+    The twitter.Api instance must be authenticated.
+
+    Args:
+      The twitter.Status instance to mark as a favorite.
+    Returns:
+      A twitter.Status instance representing the newly-marked favorite.
+    '''
+    url = self._base_url + 'favorites/create/%s.json' % id
+    json = self._FetchUrl(url, post_data={})
+    data = simplejson.loads(json)
+    self._CheckForTwitterError(data)
+    return Status.NewFromJsonDict(data)
+
   def DestroyFavorite(self, status):
     '''Un-favorites the status specified in the ID parameter as the authenticating user.
     Returns the un-favorited status in the requested format when successful.
