@@ -38,6 +38,8 @@ import socket
 import re
 import string
 import osso
+import dbus
+import dbus.glib
 import os
 import webbrowser
 import ConfigParser
@@ -55,6 +57,7 @@ import cProfile
 import ui
 import account
 
+
 gtk.gdk.threads_init()
 
 
@@ -108,7 +111,13 @@ class Witter():
 
         self.osso_c = osso.Context("witter", self.version, False)
         self.osso_rpc = osso.Rpc(self.osso_c)
+        self.osso_rpc.set_rpc_callback("uk.wouldd.witter", "/uk/wouldd/witter", "uk.wouldd.witter", self.cb_switch_view, self.osso_c)
         # set name of application: this shows in titlebar
+        system_bus = dbus.Bus.get_system()
+        system_bus.add_signal_receiver(self._on_orientation_signal, \
+                 signal_name='sig_device_orientation_ind', \
+                 dbus_interface='com.nokia.mce.signal', \
+                 path='/com/nokia/mce/signal')
 
         self.twitterUrlRoot = "https://twitter.com/"
         self.twitterSearchUrlRoot = "https://search.twitter.com/"
@@ -236,6 +245,7 @@ class Witter():
 
 
     def FollowTweetAuthor(self, widget):
+        #TODO : put this on a thread
         self.activeAcount.FollowUser(widget, self.reply_to_name)
 
 
@@ -932,6 +942,19 @@ class Witter():
                 self.accounts.remove(account)
                 self.config.accountList.remove(account.getAccountData())
 
+    def cb_switch_view(self, interface, method, args, user_data):
+         if method == 'open_mentions':
+            self.ui.switchViewTo(self.ui.treeview,"mentions")
+         if method == 'open_dm':
+            self.ui.switchViewTo(self.ui.treeview,"direct")
+            
+    def _on_orientation_signal(self, orientation, stand, face, x, y, z):
+         if (orientation == 'portrait'):
+            print "switched to portrait"
+            self.ui.cell.set_property('wrap-width', 400)
+         if (orientation == 'landscape'):
+            print "switched to landscape"
+            self.ui.cell.set_property('wrap-width', 730)
 
     def getVersion(self):
         return self.version
